Module blaxel.core.client.models.function_spec
==============================================

Classes
-------

`FunctionSpec(configurations: blaxel.core.client.types.Unset | ForwardRef('CoreSpecConfigurations') = <blaxel.core.client.types.Unset object>, enabled: blaxel.core.client.types.Unset | bool = <blaxel.core.client.types.Unset object>, flavors: blaxel.core.client.types.Unset | list['Flavor'] = <blaxel.core.client.types.Unset object>, integration_connections: blaxel.core.client.types.Unset | list[str] = <blaxel.core.client.types.Unset object>, policies: blaxel.core.client.types.Unset | list[str] = <blaxel.core.client.types.Unset object>, private_clusters: blaxel.core.client.types.Unset | ForwardRef('ModelPrivateCluster') = <blaxel.core.client.types.Unset object>, revision: blaxel.core.client.types.Unset | ForwardRef('RevisionConfiguration') = <blaxel.core.client.types.Unset object>, runtime: blaxel.core.client.types.Unset | ForwardRef('Runtime') = <blaxel.core.client.types.Unset object>, sandbox: blaxel.core.client.types.Unset | bool = <blaxel.core.client.types.Unset object>, description: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, kit: blaxel.core.client.types.Unset | list['FunctionKit'] = <blaxel.core.client.types.Unset object>, schema: blaxel.core.client.types.Unset | ForwardRef('FunctionSchema') = <blaxel.core.client.types.Unset object>)`
:   Function specification
    
    Attributes:
        configurations (Union[Unset, CoreSpecConfigurations]): Optional configurations for the object
        enabled (Union[Unset, bool]): Enable or disable the resource
        flavors (Union[Unset, list['Flavor']]): Types of hardware available for deployments
        integration_connections (Union[Unset, list[str]]):
        policies (Union[Unset, list[str]]):
        private_clusters (Union[Unset, ModelPrivateCluster]): Private cluster where the model deployment is deployed
        revision (Union[Unset, RevisionConfiguration]): Revision configuration
        runtime (Union[Unset, Runtime]): Set of configurations for a deployment
        sandbox (Union[Unset, bool]): Sandbox mode
        description (Union[Unset, str]): Function description, very important for the agent function to work with an LLM
        kit (Union[Unset, list['FunctionKit']]): Function kits
        schema (Union[Unset, FunctionSchema]): Function schema
    
    Method generated by attrs for class FunctionSpec.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `configurations`
    :

    `description`
    :

    `enabled`
    :

    `flavors`
    :

    `integration_connections`
    :

    `kit`
    :

    `policies`
    :

    `private_clusters`
    :

    `revision`
    :

    `runtime`
    :

    `sandbox`
    :

    `schema`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :